<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BioStruct3DSubsetEditor</name>
    <message>
        <location filename="../src/BioStruct3DSubsetEditor.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSubsetEditor.ui" line="20"/>
        <source>Structure</source>
        <translation>Структура</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSubsetEditor.ui" line="37"/>
        <source>Chain</source>
        <translation>Цепь</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSubsetEditor.ui" line="54"/>
        <source>Region</source>
        <translation>Регион</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSubsetEditor.ui" line="64"/>
        <source>Model</source>
        <translation>Модель</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/TubeGLRenderer.cpp" line="30"/>
        <source>Tubes</source>
        <translation>Трубки</translation>
    </message>
    <message>
        <location filename="../src/WormsGLRenderer.cpp" line="33"/>
        <source>Worms</source>
        <translation>Каркас</translation>
    </message>
    <message>
        <location filename="../src/VanDerWaalsGLRenderer.cpp" line="36"/>
        <source>Space Fill</source>
        <translation>Заполнение</translation>
    </message>
    <message>
        <location filename="../src/MolecularSurfaceRenderer.cpp" line="67"/>
        <source>Dots</source>
        <translation>Точки</translation>
    </message>
    <message>
        <location filename="../src/MolecularSurfaceRenderer.cpp" line="68"/>
        <source>Convex Map</source>
        <translation>Выпуклая структура</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DColorScheme.cpp" line="78"/>
        <source>Molecular Chains</source>
        <translation>Молекулярные цепи</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DColorScheme.cpp" line="79"/>
        <source>Chemical Elements</source>
        <translation>Химические элементы</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DColorScheme.cpp" line="80"/>
        <source>Secondary Structure</source>
        <translation>Вторичная структура</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DColorScheme.cpp" line="81"/>
        <source>Simple colors</source>
        <translation>Простые цвета</translation>
    </message>
</context>
<context>
    <name>SelectModelsDialog</name>
    <message>
        <location filename="../src/SelectModelsDialog.ui" line="14"/>
        <source>Select Models</source>
        <translation>Выбор моделей</translation>
    </message>
    <message>
        <location filename="../src/SelectModelsDialog.ui" line="25"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../src/SelectModelsDialog.ui" line="32"/>
        <source>Invert</source>
        <translation>Инвертировать</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.ui" line="35"/>
        <source>Anaglyph view</source>
        <translation>Стереоизображение</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="49"/>
        <source>Eyes shift</source>
        <translation>Сдвиг слоев</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="279"/>
        <source>Set background color...</source>
        <translation>Выбрать цвет фона...</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="292"/>
        <source>Set selection color...</source>
        <translation>Выбрать цвет выделения...</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="301"/>
        <source>Detail level</source>
        <translation>Уровень детализации</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="325"/>
        <source>Unselected regions shading</source>
        <translation>Затемнение невыбранных регионов</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="96"/>
        <source>Glasses colors</source>
        <translation>Цвета очков</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="125"/>
        <source>Left</source>
        <translation>Левый</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="135"/>
        <source>Right</source>
        <translation>Правый</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.ui" line="254"/>
        <source>Swap colors</source>
        <translation>Поменять местами</translation>
    </message>
</context>
<context>
    <name>StructuralAlignmentDialog</name>
    <message>
        <location filename="../src/StructuralAlignmentDialog.ui" line="14"/>
        <source>Structural Alignment</source>
        <translation>Структурное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/StructuralAlignmentDialog.ui" line="20"/>
        <source>Algorithm</source>
        <translation>Алгоритм</translation>
    </message>
    <message>
        <location filename="../src/StructuralAlignmentDialog.ui" line="45"/>
        <source>Reference</source>
        <translation>Референсная</translation>
    </message>
    <message>
        <location filename="../src/StructuralAlignmentDialog.ui" line="61"/>
        <source>Mobile</source>
        <translation>Мобильная</translation>
    </message>
</context>
<context>
    <name>U2::AddModelToSplitterTask</name>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="756"/>
        <source>Add 3d model &apos;%1&apos; to BioStruct3DSplitter</source>
        <translation>Добавить 3D модель &apos;%1&apos; в BioStruct3DSplitter</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="779"/>
        <source>Model %1 wasn&apos;t added</source>
        <translation>Модель %1 не была добавлена</translation>
    </message>
</context>
<context>
    <name>U2::BioStruct3DGLWidget</name>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="769"/>
        <source>Spin</source>
        <translation>Вращение</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="758"/>
        <source>Off</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="765"/>
        <source>Models..</source>
        <translation>Модели..</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="787"/>
        <source>Align With...</source>
        <translation>Выровнять с...</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="807"/>
        <source>Molecular Surface Render Style</source>
        <translation>Стиль отрисовки поверхности</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="811"/>
        <source>Molecular Surface</source>
        <translation>Молекулярная поверхность</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="564"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="564"/>
        <source>Unable to open file %1 for writing</source>
        <translation>Невозможно открыть файл %1 для записи</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="659"/>
        <source>The &quot;3D Structure Viewer&quot; was disabled, because OpenGL has error </source>
        <translation>3D визуализация отключена: не удалось инициализировать OpenGL </translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="773"/>
        <source>Settings...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="776"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="779"/>
        <source>Export Image...</source>
        <translation>Экспортировать изображение...</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="791"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="797"/>
        <source>Render Style</source>
        <translation>Стиль отрисовки</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="802"/>
        <source>Coloring Scheme</source>
        <translation>Цветовая схема</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="838"/>
        <source>Structural Alignment</source>
        <translation>Структурное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="988"/>
        <source>Molecular surface calculation task for %1</source>
        <translation>Задача расчета модекулярной поверхности для %1</translation>
    </message>
</context>
<context>
    <name>U2::BioStruct3DSettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="48"/>
        <source>Custom</source>
        <translation>Выбранные</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="50"/>
        <source>Red - Blue</source>
        <translation>Красный - Синий</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="51"/>
        <source>Cyan - Red</source>
        <translation>Голубой - Красный</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="52"/>
        <source>Red - Dark Cyan</source>
        <translation>Красный - Темно-голубой</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="53"/>
        <source>Red - Green</source>
        <translation>Красный - Зеленый</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="54"/>
        <source>Magenta - Green</source>
        <translation>Пурпурный - Зеленый</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="223"/>
        <source>(not supported by your videocard)</source>
        <translation>(не поддерживается видеокартой)</translation>
    </message>
</context>
<context>
    <name>U2::BioStruct3DViewContext</name>
    <message>
        <location filename="../src/BioStruct3DViewPlugin.cpp" line="180"/>
        <source>Close 3D Structure Viewer</source>
        <translation>Закрыть визуализатор 3D структур</translation>
    </message>
</context>
<context>
    <name>U2::BioStruct3DViewPlugin</name>
    <message>
        <location filename="../src/BioStruct3DViewPlugin.cpp" line="81"/>
        <source>Unfortunately, your system does not have OpenGL Support.
The 3D Structure Viewer is not available.
You may try to upgrade your system by updating the video card driver.</source>
        <translation>Unfortunately, your system does not have OpenGL Support.
The 3D Structure Viewer is not available.
You may try to upgrade your system by updating the video card driver.</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DViewPlugin.cpp" line="87"/>
        <source>3D Structure Viewer</source>
        <translation>Визуализатор 3D структур</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DViewPlugin.cpp" line="87"/>
        <source>Visualizes 3D structures of biological molecules.</source>
        <translation>Визуализирует 3D структуры биологических молекул.</translation>
    </message>
</context>
<context>
    <name>U2::SelectModelsDialog</name>
    <message>
        <location filename="../src/SelectModelsDialog.cpp" line="73"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/SelectModelsDialog.cpp" line="73"/>
        <source>At least one model should be selected.</source>
        <translation>Выберите как минимум одну модель.</translation>
    </message>
</context>
<context>
    <name>U2::SplitterHeaderWidget</name>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="380"/>
        <source>3D Structure Viewer</source>
        <translation>Визуализатор 3D структур</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="388"/>
        <source>Active view:</source>
        <translation>Активная:</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="395"/>
        <source>Restore Default View</source>
        <translation>Восстановить вид по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="400"/>
        <source>Zoom In</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="406"/>
        <source>Zoom Out</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="411"/>
        <source>Synchronize 3D Structure Views</source>
        <translation>Синхронизировать изображения</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="416"/>
        <source>Display</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="440"/>
        <location filename="../src/BioStruct3DSplitter.cpp" line="441"/>
        <source>Toggle view</source>
        <translation>Переключить вид</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="528"/>
        <source>Show %1</source>
        <translation>Показывать %1</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="724"/>
        <source>File not found: %1</source>
        <translation>Файл не найден: %1</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="736"/>
        <source>Illegal entry: %1</source>
        <translation>Некорректные входные данные: %1</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="422"/>
        <source>Links</source>
        <translation>Ссылки</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="429"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
</context>
<context>
    <name>U2::StructuralAlignmentDialog</name>
    <message>
        <location filename="../src/StructuralAlignmentDialog.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/StructuralAlignmentDialog.cpp" line="63"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
</TS>
